Changelog
=========

1.7 (2023-04-05)
----------------

- Update versions to Plone 6 [erral]


1.6 (2022-09-22)
----------------

- update logrotate path [Mikel Larreategi <mlarreategi@codesyntax.com>]

- set default Plone version to 5.2.9 [Mikel Larreategi <mlarreategi@codesyntax.com>]

- set default security policies in nginx [Mikel Larreategi <mlarreategi@codesyntax.com>]

- Update nginx_ssl_http2.tpl [Mikel Larreategi <mlarreategi@codesyntax.com>]

- Update nginx_ssl_http2.tpl [Mikel Larreategi <mlarreategi@codesyntax.com>]

-  [Mikel Larreategi <mlarreategi@codesyntax.com>]

- [ci skip] [Mikel Larreategi <mlarreategi@codesyntax.com>]



1.5 (2022-04-06)
----------------

- New Volto backend template
  [ionlizarazu]


1.4.1 (2021-10-22)
------------------

- change the section that eggs come from: Zope2 and Plone are define in instance, so they should come from there [Mikel Larreategi <mlarreategi@codesyntax.com>]

-  [Mikel Larreategi <mlarreategi@codesyntax.com>]

- [ci skip] [Mikel Larreategi <mlarreategi@codesyntax.com>]



1.4 (2021-10-21)
----------------

- add egg option to the zeo part, to be able to do conflict-resolution [Mikel Larreategi <mlarreategi@codesyntax.com>]

-  [Mikel Larreategi <mlarreategi@codesyntax.com>]

- [ci skip] [Mikel Larreategi <mlarreategi@codesyntax.com>]



1.3.1 (2021-08-31)
------------------

- Fix user import blueprint (fullname)
  [erral]


1.3 (2021-08-30)
----------------

- User migration blueprint and new version pins
  [erral]

- update version pins
  [erral]


1.2.4 (2020-10-16)
------------------

- Default to Plone 5.2.2
  [erral]

- Update version pins.
  [erral]


1.2.3 (2020-02-19)
------------------

- Update haproxy
  [erral]

- Use new Travis.
  [erral]


1.2.2 (2020-01-21)
------------------

- Use `+=` in buildout part eggs link to make hotfix installation from external versions file work
  [erral]

- Update supervisor version pins.
  [erral]


1.2.1 (2019-05-15)
------------------

- Remove 'products' directory registration for buildout recipe
  [erral]

- update varnish control script in supervisor.
  [erral]


1.2 (2019-04-04)
----------------

- Always cache Diazo rules in development
  [erral]

- Enable WSGI
  [erral]

- Update pinnings
  [erral]

- Remove checkinterval calculation.
- Python3 compatibility fixes
  [erral]


1.1.4 (2019-01-24)
------------------

- Fix template registration
  [erral]


1.1.3 (2019-01-24)
------------------

- Minor fixes in template registration.
  [erral]


1.1.2 (2019-01-16)
------------------

- Bugfixes in migration subtemplate.
  [erral]


1.1.1 (2018-11-26)
------------------

- Minor fix.
  [erral]

1.1 (2018-11-26)
----------------

- Add a subtemplate with migration utils.
  [erral]


1.0.0 (2018-10-19)
------------------

- Link to starzel buildout for hotfix installation
  [erral]

- Improve docs
  [erral]

- More tests
  [erral]

1.0b1 (2018-10-18)
------------------

- No changes yet.
